Frendoz

# CSS

- Home
- Text demo
- Form demo
- Table demo
- Tiles demo

# Javascript

- Autocomplete
- List Actions
- Modal
- Color palette
- Ajax

# List Heading with action icons

cAMAN OPE 1 26/03/2020 09:21 | Opérationnel
aAMAN OPE 1 26/03/2020 09:21 | Test
jtest zob 25 ORT 26/03/2020 09:21 | Electra
bAMAN OPE 1 26/03/2020 09:21 | 4SIM

Lorem ipsum dolor. Ut wisi enim ad minim veniam, quis nostrud exerci tation ullamcorper suscipit lobortis nisl ut aliquip ex ea commodo consequat.